@@ -5,11 +5,12 @@ import os, string
 from AccessControl import ClassSecurityInfo
 import Globals
 from OFS.ObjectManager import bad_id
+from StructuredText.StructuredText import HTML
 from ZPublisher.Publish import call_object, missing_name, dont_publish_class
 from ZPublisher.mapply import mapply
 from Products.CMFFormController import GLOBALS as fc_globals
-from Products.CMFCore.utils import getToolByName, UniqueObject, SimpleItemWithProperties, format_stx
-from Products.CMFCore.CMFCorePermissions import ManagePortal
+from Products.CMFCore.utils import getToolByName, UniqueObject, SimpleItemWithProperties
+from Products.CMFCore.permissions import ManagePortal
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from Products.CMFFormController.ControllerState import ControllerState
 from FormAction import FormActionType, FormActionKey, FormAction, FormActionContainer
@@ -71,7 +72,7 @@ class FormController(UniqueObject, SimpleItemWithProperties):
     f = open(os.path.join(wwwpath, 'docs.stx'), 'r')
     _docs = f.read()
     f.close()
-    _docs = format_stx(_docs)
+    _docs = HTML(_docs)
 
 
     def __init__(self):
@@ -137,14 +138,14 @@ class FormController(UniqueObject, SimpleItemWithProperties):
 
 
     security.declareProtected(ManagePortal, 'listFormValidators')
-    def listFormValidators(self, override, **kwargs):
+    def listFormValidators(self, override=None, **kwargs):
         """Return a list of existing validators.  Validators can be filtered by
            specifying required attributes via kwargs"""
         return self.validators.getFiltered(**kwargs)
 
 
     security.declareProtected(ManagePortal, 'listFormActions')
-    def listFormActions(self, override, **kwargs):
+    def listFormActions(self, override=None, **kwargs):
         """Return a list of existing actions.  Actions can be filtered by
            specifying required attributes via kwargs"""
         return self.actions.getFiltered(**kwargs)
@@ -270,7 +271,7 @@ class FormController(UniqueObject, SimpleItemWithProperties):
         return REQUEST.RESPONSE.redirect(self.absolute_url()+'/manage_formActionsForm')
 
 
-    security.declarePrivate('_delFormAction')
+    security.declarePrivate('_delFormActions')
     def _delFormActions(self, container, REQUEST):
         for k in REQUEST.form.keys():
             if k.startswith('del_id_'):
@@ -351,8 +352,10 @@ class FormController(UniqueObject, SimpleItemWithProperties):
                 kwargs = argdict
             else:
                 kwargs = {}
-                for k, v in REQUEST.items():
-                    kwargs[k] = v
+                for k in REQUEST.keys():
+                    if k in ('SESSION',):
+                        continue
+                    kwargs[k] = REQUEST[k]
                 kwargs.update(argdict)
         context = controller_state.getContext()
         if validators is None:
@@ -415,7 +418,7 @@ class FormController(UniqueObject, SimpleItemWithProperties):
         return text
 
 
-    security.declareProtected(ManagePortal, 'purge')
+    security.declareProtected(ManagePortal, '_purge')
     def _purge(self):
         """Remove actions and validators for ids that no longer correspond to
         objects in the portal"""
@@ -430,7 +433,6 @@ class FormController(UniqueObject, SimpleItemWithProperties):
 
         def fn(obj, dict):
             dict[obj.getId()] = 0
-            print str(dict)
         meta_types = ['Controller Page Template', 'Controller Page Template (File)', 'Filesystem Controller Page Template', 'Controller Python Script', 'Filesystem Controller Python Script']
         portal = getToolByName(self, 'portal_url').getPortalObject()
         catalog = getToolByName(self, 'portal_catalog')
