@@ -2,15 +2,15 @@
 # Test copying/pasting of controller objects
 #
 
-import os, sys
-if __name__ == '__main__':
-    execfile(os.path.join(sys.path[0], 'framework.py'))
+import unittest
 
 from Testing import ZopeTestCase
-from Products.CMFPlone.tests import PloneTestCase
-from Products.CMFFormController.tests import transaction
+from Products.PloneTestCase import PloneTestCase
+PloneTestCase.setupPloneSite()
+
 from Products.CMFFormController.FormAction import FormAction
 from Products.CMFFormController.FormValidator import FormValidator
+import transaction
 
 class TestCopyRename(PloneTestCase.PloneTestCase):
 
@@ -37,7 +37,7 @@ class TestCopyRename(PloneTestCase.PloneTestCase):
 
         transaction.savepoint(optimistic=True)
 
-        self.loginPortalOwner()
+        self.loginAsPortalOwner()
         self.folder.manage_renameObjects(['test'], ['test2'])
         pt2 = self.folder.test2
         self.assertEqual(len(pt2.actions.getFiltered(object_id='test')), 0)
@@ -77,7 +77,7 @@ class TestCopyRename(PloneTestCase.PloneTestCase):
 
         transaction.savepoint(optimistic=True)
 
-        self.loginPortalOwner()
+        self.loginAsPortalOwner()
         cb = self.folder.manage_copyObjects(['test'])
         self.folder.manage_pasteObjects(cb)
         pt2 = self.folder.copy_of_test
@@ -97,14 +97,10 @@ class TestCopyRename(PloneTestCase.PloneTestCase):
         self.assertEqual(formcontroller.validators.match('copy_of_test', 'Document', 'submit').getValidators(), ['d','e','f'])
         self.assertEqual(formcontroller.validators.match('test', 'Document', 'submit').getValidators(), ['d','e','f'])
 
-        
-#        self.assertEqual(temp_doc.meta_type, 'Document')
-
 def test_suite():
-    from unittest import TestSuite, makeSuite
-    suite = TestSuite()
-    suite.addTest(makeSuite(TestCopyRename))
+    suite = unittest.TestSuite()
+    suite.addTest(unittest.makeSuite(TestCopyRename))
     return suite
 
 if __name__ == '__main__':
-    framework()
+    unittest.main(defaultTest="test_suite")
